# mdslicer

[![pipeline status](https://github.com/boileaum/mdslicer/actions/workflows/main.yml/badge.svg)](https://github.com/boileaum/mdslicer/actions)
[![cov](https://https://boileaum.github.io/mdslicer/badges/coverage.svg)](https://github.com/boileaum/mdslicer)
[![Latest Release](https://img.shields.io/github/v/release/boileaum/mdslicer?label=release)](https://github.com/boileaum/mdslicer/releases)
[![Doc](https://img.shields.io/badge/doc-sphinx-blue)](https://boileaum.github.io/mdslicer)

A library to slice a markdown file into HTML sections.

## Features

* TODO
* More TODO

See [Documentation](https://boileaum.github.io/mdslicer) for details.
